=====
Notes
=====

For Japanese / Chinese website
------------------------------

This project depends on only ``pagefind[bin]``
and ``pagefind_extended`` is not included in it.

If you index Japanese and Chinese pages,
please we recommend to install ``pagefind[extended]`` together it. [#]_

.. code-block:: console

   pip install 'pagefind[extendes]'

.. [#] Pagefind find ``pagefind_extended`` automately without extra settings.
